# CLAUDE.md

This file provides guidance to Claude Code (claude.ai/code) when working with code in this repository.

## Project Overview

Cryptex is a **zero-config** temporal isolation engine for AI/LLM applications. It provides bulletproof secrets isolation with **zero cognitive overhead** - one decorator line = complete temporal isolation.

**Key Philosophy**: No config files, no environment variables, no setup required. Built-in patterns handle 95% of real-world usage.

## Key Directories

- `src/cryptex/`: Main library source code
  - `decorators/`: Universal decorator implementation
  - `patterns/`: Pattern system with base classes and registry
  - `core/`: Temporal isolation engine and security components
- `tests/`: Comprehensive test suite (unit, integration, security, performance)
- `examples/`: Working examples demonstrating zero-config usage
- `Makefile`: Development workflow automation
- `.github/`: CI/CD workflows

## Development Workflow

### Available Command-Line Tools
- **uv**: A single tool to replace pip, pip-tools, pipx, poetry, pyenv, twine, virtualenv, and more. See: https://github.com/astral-sh/uv
  - Use uv for Python Package & environment management
- **zoxide**: A fast alternative to cd that learns your habits. See: https://github.com/ajeetdsouza/zoxide
- **eza**: A replacement for 'ls'. See: https://github.com/eza-community/eza
- **fd**: A simple, fast and user-friendly alternative to find. See: https://github.com/sharkdp/fd

### Essential Make Commands

```bash
# Development setup
make dev-setup              # Complete environment setup
make test                   # Run all tests
make lint                   # Code quality checks
make format                 # Code formatting
make pre-commit             # All quality gates

# Available as slash commands
/make:test, /make:lint, /make:format, etc.
```

[... rest of the file remains unchanged ...]